@@ -1,5 +1,6 @@
 //TODO this needs rework: 
 //rugraph::Graph and rugraph::MultiDiGraph
 pub mod rugraph;
-
+pub mod graph;
+pub mod digraph;
 pub mod multidigraph;
\ No newline at end of file
